@@ -8,20 +8,35 @@ module Byebug
   class DeleteCommand < Command
     include Helpers::ParseHelper
 
-    self.allow_in_post_mortem = false
     self.allow_in_control = true
+    self.allow_in_post_mortem = true
 
-    def regexp
+    def self.regexp
       /^\s* del(?:ete)? (?:\s+(.*))?$/x
     end
 
+    def self.description
+      <<-EOD
+        del[ete][ nnn...]
+
+        #{short_description}
+
+        Without and argument, deletes all breakpoints. With integer arguments,
+        it deletes specific breakpoints.
+      EOD
+    end
+
+    def self.short_description
+      'Deletes breakpoints'
+    end
+
     def execute
       unless @match[1]
         if confirm(pr('break.confirmations.delete_all'))
           Byebug.breakpoints.clear
         end
 
-        return nil
+        return
       end
 
       @match[1].split(/ +/).each do |number|
@@ -29,19 +44,12 @@ module Byebug
 
         return errmsg(err) unless pos
 
-        unless Breakpoint.remove(pos)
-          return errmsg(pr('break.errors.no_breakpoint_delete', pos: pos))
+        if Breakpoint.remove(pos)
+          puts(pr('break.messages.breakpoint_deleted', pos: pos))
+        else
+          errmsg(pr('break.errors.no_breakpoint_delete', pos: pos))
         end
       end
     end
-
-    def description
-      <<-EOD
-        del[ete][ nnn...]
-
-        Without and argument, deletes all breakpoints. With integer arguments,
-        it deletes specific breakpoints.
-      EOD
-    end
   end
 end
