@@ -8,22 +8,16 @@ module Byebug
     #
     # Enables all or specific breakpoints
     #
-    class BreakpointsSubcommand < Command
+    class BreakpointsCommand < Command
       include Helpers::ToggleHelper
 
-      def regexp
+      self.allow_in_post_mortem = true
+
+      def self.regexp
         /^\s* b(?:reakpoints)? (?:\s+ (.+))? \s*$/x
       end
 
-      def execute
-        enable_disable_breakpoints('enable', @match[1])
-      end
-
-      def short_description
-        'Disable all or specific breakpoints'
-      end
-
-      def description
+      def self.description
         <<-EOD
           en[able] b[reakpoints][ <ids>]
 
@@ -33,6 +27,14 @@ module Byebug
           argument at all if you want to enable every breakpoint.
         EOD
       end
+
+      def self.short_description
+        'Enable all or specific breakpoints'
+      end
+
+      def execute
+        enable_disable_breakpoints('enable', @match[1])
+      end
     end
   end
 end
