@@ -7,33 +7,39 @@ module Byebug
   class KillCommand < Command
     self.allow_in_control = true
 
-    def regexp
+    def self.regexp
       /^\s* (?:kill) \s* (?:\s+(\S+))? \s*$/x
     end
 
+    def self.description
+      <<-EOD
+        kill[ signal]
+
+        #{short_description}
+
+        Equivalent of Process.kill(Process.pid)
+      EOD
+    end
+
+    def self.short_description
+      'Sends a signal to the current process'
+    end
+
     def execute
       if @match[1]
         signame = @match[1]
+
         unless Signal.list.member?(signame)
-          errmsg("signal name #{signame} is not a signal I know about\n")
-          return false
+          return errmsg("signal name #{signame} is not a signal I know about\n")
         end
-        @state.interface.close if 'KILL' == signame
       else
         return unless confirm('Really kill? (y/n) ')
+
         signame = 'KILL'
       end
 
+      processor.interface.close if signame == 'KILL'
       Process.kill(signame, Process.pid)
     end
-
-    def description
-      <<-EOD
-        kill[ signal]
-
-        Send [signal] to Process.pid
-        Equivalent of Process.kill(Process.pid)
-      EOD
-    end
   end
 end
