@@ -6,11 +6,31 @@ module Byebug
   #
   class SaveCommand < Command
     self.allow_in_control = true
+    self.allow_in_post_mortem = true
 
-    def regexp
+    def self.regexp
       /^\s* sa(?:ve)? (?:\s+(\S+))? \s*$/x
     end
 
+    def self.description
+      <<-EOD
+        save[ FILE]
+
+        #{short_description}
+
+        Byebug state is saved as a script file. This includes breakpoints,
+        catchpoints, display expressions and some settings. If no filename is
+        given, byebug will fabricate one.
+
+        Use the "source" command in another debug session to restore the saved
+        file.
+      EOD
+    end
+
+    def self.short_description
+      'Saves current byebug session to a file'
+    end
+
     def execute
       file = File.open(@match[1] || Setting[:savefile], 'w')
 
@@ -23,18 +43,6 @@ module Byebug
       file.close
     end
 
-    def description
-      <<-EOD
-        save[ FILE]
-
-        Saves current byebug state to FILE as a script file. This includes
-        breakpoints, catchpoints, display expressions and some settings. If no
-        filename is given, we will fabricate one.
-
-        Use the "source" command in another debug session to restore them.
-      EOD
-    end
-
     private
 
     def save_breakpoints(file)
@@ -50,11 +58,11 @@ module Byebug
     end
 
     def save_displays(file)
-      @state.display.each { |d| file.puts "display #{d[1]}" if d[0] }
+      Byebug.displays.each { |d| file.puts "display #{d[1]}" if d[0] }
     end
 
     def save_settings(file)
-      %w(autoeval autoirb autolist basename).each do |setting|
+      %w[autoirb autolist basename].each do |setting|
         file.puts "set #{setting} #{Setting[setting.to_sym]}"
       end
     end
