@@ -8,7 +8,7 @@ module Byebug
       # Reads lines of source file +filename+ into an array
       #
       def get_lines(filename)
-        File.foreach(filename).reduce([]) { |a, e| a << e.chomp }
+        File.foreach(filename).reduce([]) { |acc, elem| acc << elem.chomp }
       end
 
       #
@@ -26,20 +26,35 @@ module Byebug
       # one-line-at-a-time way.
       #
       def n_lines(filename)
-        File.foreach(filename).reduce(0) { |a, _e| a + 1 }
+        File.foreach(filename).reduce(0) { |acc, _elem| acc + 1 }
       end
 
       #
       # Regularize file name.
       #
       def normalize(filename)
-        return filename if ['(irb)', '-e'].include?(filename)
+        return filename if virtual_file?(filename)
 
         return File.basename(filename) if Setting[:basename]
 
-        path = File.expand_path(filename)
+        File.exist?(filename) ? File.realpath(filename) : filename
+      end
 
-        File.exist?(path) ? File.realpath(path) : filename
+      #
+      # A short version of a long path
+      #
+      def shortpath(fullpath)
+        components = Pathname(fullpath).each_filename.to_a
+        return fullpath if components.size <= 2
+
+        File.join('...', components[-3..-1])
+      end
+
+      #
+      # True for special files like -e, false otherwise
+      #
+      def virtual_file?(name)
+        ['(irb)', '-e', '(byebug)', '(eval)'].include?(name)
       end
     end
   end
