@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'byebug/setting'
 
 module Byebug
@@ -5,7 +7,7 @@ module Byebug
   # Setting to customize the verbosity level for stack frames.
   #
   class CallstyleSetting < Setting
-    DEFAULT = 'long'
+    DEFAULT = 'long'.freeze
 
     def banner
       'Set how you want method call parameters to be displayed'
